"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from skylight_sdk.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class InstancesTypedDict(TypedDict):
    pass


class Instances(BaseModel):
    pass


class VMInstancesListResponseTypedDict(TypedDict):
    instances: List[InstancesTypedDict]
    r"""List of instances associated with the API key"""


class VMInstancesListResponse(BaseModel):
    instances: List[Instances]
    r"""List of instances associated with the API key"""
