"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from skylight_sdk.types import BaseModel
from typing_extensions import TypedDict


class VMStartResponseTypedDict(TypedDict):
    status: str
    r"""Status of the VM start operation"""
    instance_id: str
    r"""Unique identifier of the created VM instance"""
    message: str
    r"""Human-readable status message"""


class VMStartResponse(BaseModel):
    status: str
    r"""Status of the VM start operation"""

    instance_id: str
    r"""Unique identifier of the created VM instance"""

    message: str
    r"""Human-readable status message"""
